# strats-oanda

<p>
<a href="https://github.com/kazukiyoshida/strats-oanda/actions?query=event%3Apush+branch%3Amain" target="_blank">
  <img src="https://github.com/kazukiyoshida/strats-oanda/actions/workflows/test.yaml/badge.svg" alt="Test">
</a>
<a href="https://pypi.org/project/strats-oanda" target="_blank">
  <img src="https://img.shields.io/pypi/v/strats-oanda?label=pypi%20package&color=%2334D058" alt="PyPI - Version">
</a>
</p>
